# CEBTP

This package provides functions to preprocess EEG and feature data for cebtp.

## Installation

You can install the package using pip:

```bash
pip install git+https://github.com/yourusername/cebtp.git
